intelmq.bots.experts.national_cert_contact_certat package — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.experts.national_cert_contact_certat package

## Submodules

## intelmq.bots.experts.national_cert_contact_certat.expert module

CERT.at geolocate the national CERT abuse service https://contacts.cert.at/cgi-bin/abuse-nationalcert.pl

HTTP GET: https://contacts.cert.at/cgi-bin/abuse-nationalcert.pl?ip=1.2.3.4 HTTP POST: https://contacts.cert.at/cgi-bin/abuse-nationalcert.pl

Options: &bShowNationalCERT=on Show national CERT contact info &bShowHeader=on Display a CSV header &bVerbose=on Display the source of the data, and other information &bFilter=off Act as a filter: only show lines which geolocate to “AT” &bKeepLoglines=off Keep original log lines (separated by “#”) &sep={TAB, comma, semicolon, pipe} Separator for the (output) CSV format

`intelmq.bots.experts.national_cert_contact_certat.expert.` `BOT`

  alias of `intelmq.bots.experts.national_cert_contact_certat.expert.NationalCERTContactCertATExpertBot`

class `intelmq.bots.experts.national_cert_contact_certat.expert.` `NationalCERTContactCertATExpertBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  `init`()
  `process`()

## Module contents